summaryrefslogtreecommitdiffstats
path: root/lib/public/share.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/share.php')
-rw-r--r--lib/public/share.php23
1 files changed, 20 insertions, 3 deletions
diff --git a/lib/public/share.php b/lib/public/share.php
index 4306c1b038f..acda709b552 100644
--- a/lib/public/share.php
+++ b/lib/public/share.php
@@ -64,14 +64,15 @@ class Share extends \OC\Share\Constants {
/**
* Find which users can access a shared item
* @param string $path to the file
* @param string $user owner of the file
* @param bool $includeOwner include owner to the list of users with access to the file
+ * @param bool $returnUserPaths Return an array with the user => path map
* @return array
* @note $path needs to be relative to user data dir, e.g. 'file.txt'
* not '/admin/data/file.txt'
*/
- public static function getUsersSharingFile($path, $user, $includeOwner = false) {
- return \OC\Share\Share::getUsersSharingFile($path, $user, $includeOwner);
+ public static function getUsersSharingFile($path, $ownerUser, $includeOwner = false, $returnUserPaths = false) {
+ return \OC\Share\Share::getUsersSharingFile($path, $ownerUser, $includeOwner, $returnUserPaths);
}
/**
@@ -90,6 +91,22 @@ class Share extends \OC\Share\Constants {
}
/**
+ * Get the items of item type shared with a user
+ * @param string Item type
+ * @param sting user id for which user we want the shares
+ * @param int Format (optional) Format type must be defined by the backend
+ * @param mixed Parameters (optional)
+ * @param int Number of items to return (optional) Returns all by default
+ * @param bool include collections (optional)
+ * @return Return depends on format
+ */
+ public static function getItemsSharedWithUser($itemType, $user, $format = self::FORMAT_NONE,
+ $parameters = null, $limit = -1, $includeCollections = false) {
+
+ return \OC\Share\Share::getItemsSharedWithUser($itemType, $user, $format, $parameters, $limit, $includeCollections);
+ }
+
+ /**
* Get the item of item type shared with the current user
* @param string $itemType
* @param string $itemTarget
@@ -64,14 +64,15 @@ class Share extends \OC\Share\Constants {
* Find which users can access a shared item
* @param string $path to the file
- * @param string $user owner of the file
+ * @param string $ownerUser owner of the file
* @param bool $includeOwner include owner to the list of users with access to the file